summaryrefslogtreecommitdiff
path: root/include/notification_type.h
diff options
context:
space:
mode:
authorKyuho Jo <kyuho.jo@samsung.com>2015-05-22 19:21:16 +0900
committerKyuho Jo <kyuho.jo@samsung.com>2015-05-22 19:21:16 +0900
commitb603eabe549a665887bff1c0939cbbc56dedef70 (patch)
tree86531df75eb7a77a89c4722138a8806db8ebabf3 /include/notification_type.h
parentee651486fa9a1112c466271a7c24a1f78b6f96d3 (diff)
downloadnotification-b603eabe549a665887bff1c0939cbbc56dedef70.tar.gz
notification-b603eabe549a665887bff1c0939cbbc56dedef70.tar.bz2
notification-b603eabe549a665887bff1c0939cbbc56dedef70.zip
1. Deprecated some enumerations.
2. Fixed a fault on doxygen comment. Change-Id: I89e6b3501556ea2c3e09ba164c085a5b933323fb Signed-off-by: Kyuho Jo <kyuho.jo@samsung.com>
Diffstat (limited to 'include/notification_type.h')
-rw-r--r--include/notification_type.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/include/notification_type.h b/include/notification_type.h
index 55cf56d..b40a267 100644
--- a/include/notification_type.h
+++ b/include/notification_type.h
@@ -131,7 +131,8 @@ typedef enum _notification_led_op {
} notification_led_op_e;
/**
- * @brief This will be deprecated.
+ * @deprecated Deprecated since 2.3.1
+ * @brief Enumeration for setting display type of count
* @since_tizen 2.3
*/
typedef enum _notification_count_display_type {
@@ -296,11 +297,11 @@ enum _notification_property {
NOTIFICATION_PROP_DISABLE_AUTO_DELETE = 0x00000004,
/**< Disable auto delete when it selected */
NOTIFICATION_PROP_LAUNCH_UG = 0x00000008,
/**< Will be deprecated. Notification Tray should launch application using appsvc API */
NOTIFICATION_PROP_DISABLE_TICKERNOTI = 0x00000010,
/**< Will be deprecated. Use notification_set_display_applist API */
NOTIFICATION_PROP_PERMANENT_DISPLAY = 0x00000020,
- /** < Will be deprecated. */
+ /**< The notification will not be removed (Deprecated since 2.3.1) */
NOTIFICATION_PROP_DISABLE_UPDATE_ON_INSERT = 0x00000040,/**< Disable update when it inserted. */
NOTIFICATION_PROP_DISABLE_UPDATE_ON_DELETE = 0x00000080,/**< Disable update when it deleted. */
NOTIFICATION_PROP_VOLATILE_DISPLAY = 0x00000100,/**< Deleted when device is rebooted eventhough NOTIFICATION_TYPE_NOTI type */
@@ -332,7 +333,7 @@ typedef enum _notification_op_type {
NOTIFICATION_OP_UPDATE, /**< Notification updated */
NOTIFICATION_OP_DELETE, /**< Notification deleted */
NOTIFICATION_OP_DELETE_ALL, /**< Notifications deleted */
- NOTIFICATION_OP_REFRESH, /**< Deprecated */
+ NOTIFICATION_OP_REFRESH, /**< (Deprecated Since 2.3.1) */
NOTIFICATION_OP_SERVICE_READY, /**< Notification service is ready */
} notification_op_type_e;
@@ -296,11 +297,11 @@ enum _notification_property {
/**< Disable auto delete when it selected */
NOTIFICATION_PROP_LAUNCH_UG = 0x00000008,
- /**< Will be deprecated. Notification Tray should launch application using appsvc API */
+ /**< Notification Tray should launch application using appsvc API (Deprecated since 2.3.1) */
NOTIFICATION_PROP_DISABLE_TICKERNOTI = 0x00000010,
@@ -296,11 +297,11 @@ enum _notification_property {
NOTIFICATION_PROP_DISABLE_TICKERNOTI = 0x00000010,
- /**< Will be deprecated. Use notification_set_display_applist API */
+ /**< Use notification_set_display_applist API (Deprecated since 2.3.1) */
NOTIFICATION_PROP_PERMANENT_DISPLAY = 0x00000020,